Learn R Programming

MonotoneHazardRatio (version 0.1.1)

gcm.unique: A function used to remove the repeated numbers for the computation of gcm/lcm.

Description

A function used to remove the repeated numbers for the computation of gcm/lcm.

Usage

gcm.unique(x, y)

Value

logcm GCM of the curve y~x.

Arguments

x

A vector corresponds to the independent variable.

y

A vector corresponds to the dependent variable.